@@ -6,7 +6,7 @@ for Celery and background workers in general.
 """
 
 from .amqp import AMQPClient
-from .crons import CronTask, FetchStrategy, register_crontask
+from .crons import CronStat, CronTask, FetchStrategy, register_crontask
 from .lambdas import LambdaTask, LambdaWorker, register_lambda
 from .packet import SignalPacket
 from .utils import register_tasks_with_celery_beat
@@ -17,6 +17,7 @@ __all__ = [
     "LambdaTask",
     "LambdaWorker",
     "CronTask",
+    "CronStat",
     "FetchStrategy",
     "register_lambda",
     "register_crontask",
